@@ -1,9 +1,11 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/*
+/**
  * gnome-component-ui.c: Client UI signal multiplexer and verb repository.
  *
  * Author:
- *   Michael Meeks (michael@helixcode.com)
+ *     Michael Meeks (michael@helixcode.com)
+ *
+ * Copyright 1999, 2000 Helix Code, Inc.
  */
 #include <config.h>
 #include <gnome.h>
@@ -477,7 +479,7 @@ impl_xml_get (BonoboUIComponent *component,
 		real_ev = &tmp_ev;
 	}
 
-	xml = Bonobo_UIContainer_node_get (container, path, recurse, real_ev);
+	xml = Bonobo_UIContainer_node_get (container, path, !recurse, real_ev);
 
 	if (real_ev->_major != CORBA_NO_EXCEPTION) {
 		if (!ev)
