@@ -1,24 +1,11 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
-/* bonobo-ui-toolbar.c
+/**
+ * bonobo-ui-toolbar.h
  *
- * Copyright (C) 2000  Helix Code, Inc.
+ * Author:
+ *    Ettore Perazzoli
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
- *
- * Author: Ettore Perazzoli
+ * Copyright (C) 2000 Helix Code, Inc.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -1302,7 +1289,14 @@ bonobo_ui_toolbar_insert (BonoboUIToolbar *toolbar,
 	gtk_object_sink (GTK_OBJECT (item));
 
 	priv = toolbar->priv;
-	priv->items = g_list_insert (priv->items, item, position);
+
+	/*
+	 *  This ugly hack is here since we might have unparented
+	 * a widget and then re-added it to the toolbar at a later
+	 * date, and un-parenting doesn't work quite properly yet.
+	 */
+	if (!g_list_find (priv->items, item))
+		priv->items = g_list_insert (priv->items, item, position);
 
 	gtk_signal_connect_while_alive (GTK_OBJECT (item), "destroy",
 					GTK_SIGNAL_FUNC (item_destroy_cb), toolbar,
@@ -1325,7 +1319,17 @@ bonobo_ui_toolbar_insert (BonoboUIToolbar *toolbar,
 GList *
 bonobo_ui_toolbar_get_children (BonoboUIToolbar *toolbar)
 {
+	GList *ret = NULL, *l;
+
 	g_return_val_if_fail (BONOBO_IS_UI_TOOLBAR (toolbar), NULL);
 
-	return g_list_copy (toolbar->priv->items);
+	for (l = toolbar->priv->items; l; l = l->next) {
+		GtkWidget *item_widget;
+
+		item_widget = GTK_WIDGET (l->data);
+		if (item_widget->parent != NULL) /* Unparented but still here */
+			ret = g_list_prepend (ret, item_widget);
+	}
+
+	return g_list_reverse (ret);
 }
