@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/*
+/**
  * bonobo-win.c: The Bonobo Window implementation.
  *
  * Author:
@@ -23,6 +23,7 @@
 #include <bonobo/bonobo-ui-toolbar-toggle-button-item.h>
 #include <bonobo/bonobo-ui-toolbar-separator-item.h>
 #include <bonobo/bonobo-ui-toolbar-popup-item.h>
+#include <bonobo/bonobo-ui-toolbar-control-item.h>
 
 #include <bonobo/bonobo-ui-node.h>
 #include <gnome-xml/tree.h>
@@ -141,8 +142,12 @@ info_dump_fn (BonoboUIXml *tree, BonoboUINode *node)
 			else if (attached_node != node)
 				fprintf (stderr, "Serious mismatch attaches should be '%8p'\n",
 					 node);
-			else
-				fprintf (stderr, "and matching\n");
+			else {
+				if (info->widget->parent)
+					fprintf (stderr, "and matching; parented\n");
+				else
+					fprintf (stderr, "and matching; BUT NO PARENT!\n");
+			}
  		} else
 			fprintf (stderr, " no associated widget\n");
 	} else
@@ -493,6 +498,18 @@ sync_generic_widgets (BonoboWinPrivate *priv,
 	BonoboUINode *a;
 	GList        *b, *nextb;
 
+#ifdef WIDGET_SYNC_DEBUG
+	printf ("In sync to pos %d with widgets:\n", *pos);
+	for (b = *widgets; b; b = b->next) {
+		BonoboUINode *node = widget_get_node (b->data);
+
+		if (node)
+			printf ("\t'%s'\n", bonobo_ui_xml_make_path (node));
+		else
+			printf ("\tno node ptr\n");
+	}
+#endif
+
 	b = *widgets;
 	for (a = node; a; b = nextb) {
 		gboolean same;
@@ -575,6 +592,7 @@ sync_generic_widgets (BonoboWinPrivate *priv,
 					 * on this 'b' node until a more favorable 'a'
 					 */
 					nextb = b;
+					(*pos)--;
 					g_assert (info->type | CUSTOM_WIDGET);
 #ifdef WIDGET_SYNC_DEBUG
 					printf ("not dirty & not same, but has no widget\n");
@@ -1926,19 +1944,27 @@ toolbar_build_control (BonoboWinPrivate *priv,
 		       GtkWidget        *parent)
 {
 	GtkWidget  *item;
-	GtkWidget  *control;
-
+	
 	g_return_val_if_fail (priv != NULL, NULL);
 	g_return_val_if_fail (node != NULL, NULL);
 
-	control = build_control (priv, node);
-	if (!control)
+	if (info->widget) {
+		item = info->widget;
+		g_assert (info->widget->parent == NULL);
+
+	} else if (info->object != CORBA_OBJECT_NIL) {
+		item = bonobo_ui_toolbar_control_item_new (
+			bonobo_object_dup_ref (info->object, NULL));
+		if (!item) {
+			return NULL;
+		}
+
+		info->type |= CUSTOM_WIDGET;
+	} else {
 		return NULL;
+	}
 
-	item = bonobo_ui_toolbar_item_new ();
-	gtk_container_add (GTK_CONTAINER (item), control);
-
-	gtk_widget_show (GTK_WIDGET (item));
+	gtk_widget_show (item);
 
 	bonobo_ui_toolbar_insert (BONOBO_UI_TOOLBAR (parent),
 				  BONOBO_UI_TOOLBAR_ITEM (item),
@@ -2051,6 +2077,9 @@ toolbar_sync_state (BonoboWinPrivate *priv, BonoboUINode *node,
 
 	cmd_node = cmd_get_node (priv, node);
 
+	/*FIXME: to debug control problem */
+	gtk_widget_show (widget);
+
 	if ((hidden    = bonobo_ui_node_get_attr (node, "hidden")) ||
 	    (sensitive = bonobo_ui_node_get_attr (node, "sensitive")) ||
 	    (state     = bonobo_ui_node_get_attr (node, "state"))) {
@@ -2090,10 +2119,6 @@ toolbar_sync_state (BonoboWinPrivate *priv, BonoboUINode *node,
 		g_strfreev (behavior_array);
 	}
 
-	/* if it's a control, exit now, since the rest isn't relevant */
-	if (bonobo_ui_node_has_name (node, "control"))
-		return;
-
 	icon_pixbuf = cmd_get_toolbar_pixbuf (node, cmd_node);
 
 	type = cmd_get_attr (node, cmd_node, "type");
@@ -3171,15 +3196,33 @@ construct_priv (BonoboWin *win)
 	return priv;
 }
 
+/*
+ *   To kill bug reports of hiding not working
+ * we want to stop show_all showing hidden menus etc.
+ */
+static void
+bonobo_win_show_all (GtkWidget *widget)
+{
+	BonoboWin *win = BONOBO_WIN (widget);
+
+	if (win->priv->client_area)
+		gtk_widget_show_all (win->priv->client_area);
+
+	gtk_widget_show (widget);
+}
+
 static void
 bonobo_win_class_init (BonoboWinClass *klass)
 {
 	GtkObjectClass *object_class = (GtkObjectClass *) klass;
+	GtkWidgetClass *widget_class = (GtkWidgetClass *) klass;
 
 	bonobo_win_parent_class =
 		gtk_type_class (gtk_window_get_type ());
 
 	object_class->finalize = bonobo_win_finalize;
+
+	widget_class->show_all = bonobo_win_show_all;
 }
 
 static void
