@@ -1,4 +1,4 @@
-/* $Id: component.c,v 1.14 2000/10/09 17:52:05 mmeeks Exp $ */
+/* $Id: component.c,v 1.15 2000/10/11 14:37:01 martin Exp $ */
 
 #include "component.h"
 #include "embeddable-io.h"
@@ -121,7 +121,7 @@ sample_client_site_add_frame (SampleClientSite *site)
 	 */
 	view_frame = bonobo_client_site_new_view (
 		BONOBO_CLIENT_SITE (site),
-		bonobo_ui_compat_get_container (site->app->ui_handler));
+		bonobo_object_corba_objref (BONOBO_OBJECT (site->app->ui_container)));
 	
 	/*
 	 * Embed the view frame into the application.
